""" Python Character Mapping Codec for Kamenicky encoding.

    This character scheme is compliant to RFC2319

Written by Radovan Garabik (garabik@kassiopeia.juls.savba.sk).

"""#"

import codecs, cp437

### Codec APIs

class Codec(codecs.Codec):

    def encode(self,input,errors='strict'):

        return codecs.charmap_encode(input,errors,encoding_map)

    def decode(self,input,errors='strict'):

        return codecs.charmap_decode(input,errors,decoding_map)

class StreamWriter(Codec,codecs.StreamWriter):
    pass

class StreamReader(Codec,codecs.StreamReader):
    pass

### encodings module API

def getregentry():

    return (Codec().encode,Codec().decode,StreamReader,StreamWriter)

### Decoding Map

decoding_map = cp437.decoding_map.copy()
decoding_map.update({
     0x80: 0x010c,  # LATIN CAPITAL LETTER C WITH CARON

     0x82: 0x00e9,  # LATIN SMALL LETTER E WITH ACUTE
     0x83: 0x010f,  # LATIN SMALL LETTER D WITH CARON
     0x84: 0x00e4,  # LATIN SMALL LETTER A WITH DIAERESIS
     0x85: 0x010e,  # LATIN CAPITAL LETTER D WITH CARON
     0x86: 0x0164,  # LATIN CAPITAL LETTER T WITH CARON
     0x87: 0x010d,  # LATIN SMALL LETTER C WITH CARON
     0x88: 0x011b,  # LATIN SMALL LETTER E WITH CARON
     0x89: 0x011a,  # LATIN CAPITAL LETTER E WITH CARON
     0x8a: 0x0139,  # LATIN CAPITAL LETTER L WITH ACUTE
     0x8b: 0x00cd,  # LATIN CAPITAL LETTER I WITH ACUTE
     0x8c: 0x013e,  # LATIN SMALL LETTER L WITH CARON
     0x8d: 0x013a,  # LATIN SMALL LETTER L WITH ACUTE
     0x8e: 0x00c4,  # LATIN CAPITAL LETTER A WITH DIAERESIS
     0x8f: 0x00c1,  # LATIN CAPITAL LETTER A WITH ACUTE
     0x90: 0x00c9,  # LATIN CAPITAL LETTER E WITH ACUTE
     0x91: 0x017e,  # LATIN SMALL LETTER Z WITH CARON
     0x92: 0x017d,  # LATIN CAPITAL LETTER Z WITH CARON
     0x93: 0x00f4,  # LATIN SMALL LETTER O WITH CIRCUMFLEX
     0x94: 0x00f6,  # LATIN SMALL LETTER O WITH DIAERESIS
     0x95: 0x00d3,  # LATIN CAPITAL LETTER O WITH ACUTE
     0x96: 0x016f,  # LATIN SMALL LETTER U WITH RING ABOVE
     0x97: 0x00da,  # LATIN CAPITAL LETTER U WITH ACUTE
     0x98: 0x00fd,  # LATIN SMALL LETTER Y WITH ACUTE
     0x99: 0x00d6,  # LATIN CAPITAL LETTER O WITH DIAERESIS
     0x9a: 0x00dc,  # LATIN CAPITAL LETTER U WITH DIAERESIS
     0x9b: 0x0160,  # LATIN CAPITAL LETTER S WITH CARON
     0x9c: 0x013d,  # LATIN CAPITAL LETTER L WITH CARON
     0x9d: 0x00dd,  # LATIN CAPITAL LETTER Y WITH ACUTE
     0x9e: 0x0158,  # LATIN CAPITAL LETTER R WITH CARON
     0x9f: 0x0165,  # LATIN SMALL LETTER T WITH CARON
     0xa0: 0x00e1,  # LATIN SMALL LETTER A WITH ACUTE
     0xa1: 0x00ed,  # LATIN SMALL LETTER I WITH ACUTE
     0xa2: 0x00f3,  # LATIN SMALL LETTER O WITH ACUTE
     0xa3: 0x00fa,  # LATIN SMALL LETTER U WITH ACUTE
     0xa4: 0x0148,  # LATIN SMALL LETTER N WITH CARON
     0xa5: 0x0147,  # LATIN CAPITAL LETTER N WITH CARON
     0xa6: 0x016e,  # LATIN CAPITAL LETTER U WITH RING ABOVE
     0xa7: 0x00d4,  # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
     0xa8: 0x0161,  # LATIN SMALL LETTER S WITH CARON
     0xa9: 0x0159,  # LATIN SMALL LETTER R WITH CARON
     0xaa: 0x0155,  # LATIN SMALL LETTER R WITH ACUTE
     0xab: 0x0154,  # LATIN CAPITAL LETTER R WITH ACUTE
     0xad: 0x00a7,  # SECTION SIGN

})

### Encoding Map

encoding_map = codecs.make_encoding_map(decoding_map)

